import { r as registerInstance, c as createEvent, h, F as Fragment, g as getElement } from './index-77a9c9e7.js';
import { F as Fe, E as Ex, h as gt, t as tw, x as ew, y as iw, m as mr, N as NS, r as US, R as Rg, a as Eg, q as qg, U as Ug } from './index.esm-9c337dd5.js';
import { H, Y, Q as Re, R, n as ne } from './index.esm-2526d8ff.js';
import { a4 as je, aa as te, ab as _t, ae as L, af as Gt, ag as C, U as rn, Z as tn } from './index.esm-044e39a2.js';
import { s as store } from './redux-store.service-07c5f69a.js';

const BpSdkQuestionSetContainer = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.bpAnalyticsTrack = createEvent(this, "bpAnalyticsTrack", 7);
        this.handleSubscriptions = () => {
            this.storeUnsubscribe && this.storeUnsubscribe();
            store.mapDispatchToProps(this, {
                saveQuestionSet: Fe,
                updateErrors: Ex,
                pushAnswer: gt,
                removeActiveAnswerId: tw,
                updateActiveAnswerId: ew,
                updateLockQuestionSet: iw,
            });
            this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
        };
        this.mapStateToProps = (state) => {
            return {
                questionSets: state.application.questionSets,
                config: mr(state),
                enableUserApplicationGuard: !!state.config.options.enableUserApplicationGuard,
                locked: state.application.form.locked,
                isOwner: NS(state),
                hasPermissionToEdit: US(state, {
                    permission: H.ApplicationForms,
                    action: Y.Update,
                }),
                pendingProcesses: state.application.pendingProcesses,
                queue: state.queues.answers.queue,
                answersResourceState: Rg(state),
                applicationFormResourceState: Eg(state),
                questionPoolResourceState: qg(state),
                questionSetResourceState: Ug(state),
            };
        };
        this.handleSaveQuestionSet = (questionSet) => {
            const invalidAnswers = questionSet.answers.filter((answer) => !je(answer));
            if (!invalidAnswers.length) {
                this.removeActiveAnswerId();
                this.saveQuestionSet({
                    config: this.config,
                    appFormQuestionSet: questionSet,
                    navigationDirection: 'forward',
                });
                this.bpAnalyticsTrack.emit({
                    eventName: Re.QuestionSetSaved,
                    eventPayload: {
                        applicationFormQuestionSetId: questionSet.id,
                        questionSetId: questionSet.question_set_id,
                        questionSetCode: questionSet.question_set.code,
                    },
                });
            }
            else {
                invalidAnswers.forEach((answer) => {
                    this.updateErrors({ answer, errors: te(answer) });
                });
                _t();
            }
        };
        this.questionSets = {
            list: [],
            active: '',
            activeAnswerId: '',
            completedQuestionSetAnswerHasChanged: false,
            lockQuestionSet: false,
            idOfNextActiveQuestionSetNotInState: undefined,
            parentQuestionSets: [],
        };
        this.config = undefined;
        this.answersResourceState = undefined;
        this.applicationFormResourceState = undefined;
        this.questionPoolResourceState = undefined;
        this.questionSetResourceState = undefined;
        this.locked = undefined;
        this.pendingProcesses = undefined;
        this.queue = undefined;
        this.isOwner = undefined;
        this.hasPermissionToEdit = undefined;
        this.enableUserApplicationGuard = undefined;
        this.manualLocked = false;
        this.assignedQuestionSetId = null;
        this.areResourcesReady = true;
        this.useExternal = false;
        this.canSave = true;
        this.isLocked = false;
        this.isReady = true;
        this.isFirstRun = true;
        this.isLoadingApplication = false;
    }
    resetState() {
        this.isReady = true;
        this.isFirstRun = true;
        this.isLoadingApplication = false;
    }
    connectedCallback() {
        this.resetState();
        this.handleSubscriptions();
    }
    componentWillLoad() {
        this.useExternal = !!customElements.get('bp-sdk-external-question-set-container');
        customElements
            .whenDefined('bp-sdk-external-question-set-container')
            .then(() => {
            this.useExternal = true;
        });
        this.handleSubscriptions();
        this.onAnswersResourcesStateChange(this.answersResourceState);
        this.onApplicationFormResourceStateChange(this.applicationFormResourceState);
        this.onHasPermissionToEdit(this.hasPermissionToEdit);
        this.onEnableUserApplicationGuard(this.enableUserApplicationGuard);
        this.onIsFirstRun(this.isFirstRun);
        this.onIsOwner(this.isOwner);
        this.onIsReady(this.isReady);
        this.onLocked(this.locked);
        this.onQuestionPoolResourcesStateChange(this.questionPoolResourceState);
        this.onQuestionSetResourcesStateChange(this.questionSetResourceState);
        this.onQueueChange(this.queue);
    }
    onQueueChange(queue) {
        this.canSave =
            !(queue === null || queue === void 0 ? void 0 : queue.length) && !this.doesCurrentQuestionSetHaveAPendingProcess();
    }
    onEnableUserApplicationGuard(enableUserApplicationGuard) {
        this.updateIsLocked(this.locked, this.isOwner, this.hasPermissionToEdit, enableUserApplicationGuard, this.manualLocked);
    }
    onHasPermissionToEdit(hasPermission) {
        this.updateIsLocked(this.locked, this.isOwner, hasPermission, this.enableUserApplicationGuard, this.manualLocked);
    }
    onIsOwner(isOwner) {
        this.updateIsLocked(this.locked, isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard, this.manualLocked);
    }
    onLocked(locked) {
        this.updateIsLocked(locked, this.isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard, this.manualLocked);
    }
    onManualLock(manualLocked) {
        this.updateIsLocked(this.locked, this.isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard, manualLocked);
    }
    onPendingProcessesChange(processes) {
        this.canSave = !this.doesCurrentQuestionSetHaveAPendingProcess(processes);
    }
    updateIsLocked(locked, isOwner, hasPermission, enableUserApplicationGuard, manualLocked) {
        this.isLocked =
            locked ||
                manualLocked ||
                (enableUserApplicationGuard && (!isOwner || !hasPermission));
        this.updateLockQuestionSet(this.isLocked);
    }
    onIsFirstRun(isFirstRun) {
        this.updateAreResourcesReady(isFirstRun, this.isReady);
    }
    onIsReady(isReady) {
        this.updateAreResourcesReady(this.isFirstRun, isReady);
    }
    updateAreResourcesReady(isFirstRun, isReady) {
        this.areResourcesReady = isFirstRun || isReady;
    }
    disconnectedCallback() {
        this.storeUnsubscribe && this.storeUnsubscribe();
    }
    onRemoveActiveAnswerRequest() {
        this.removeActiveAnswerId();
    }
    onUpdateActiveAnswerRequest({ detail }) {
        const answer = this.questionSets.list.reduce((acc, list) => acc || list.answers.find((answer) => answer.id === detail), null);
        if (answer) {
            this.updateActiveAnswerId(answer.id);
        }
    }
    onAnswersResourcesStateChange(state) {
        this.isReady = this.calculateResourcesReady({
            answers: state,
            applicationForm: this.applicationFormResourceState,
            questionPools: this.questionPoolResourceState,
            questionSets: this.questionSetResourceState,
        });
    }
    onApplicationFormResourceStateChange(state) {
        if (this.isFirstRun && state === R.Loaded) {
            this.isFirstRun = false;
        }
        if (state === R.Loading) {
            this.isLoadingApplication = true;
        }
        else {
            this.isLoadingApplication = false;
        }
        this.isReady = this.calculateResourcesReady({
            answers: this.answersResourceState,
            applicationForm: state,
            questionPools: this.questionPoolResourceState,
            questionSets: this.questionSetResourceState,
        });
    }
    onQuestionPoolResourcesStateChange(state) {
        this.isReady = this.calculateResourcesReady({
            answers: this.answersResourceState,
            applicationForm: this.applicationFormResourceState,
            questionPools: state,
            questionSets: this.questionSetResourceState,
        });
    }
    onQuestionSetResourcesStateChange(state) {
        this.isReady = this.calculateResourcesReady({
            answers: this.answersResourceState,
            applicationForm: this.applicationFormResourceState,
            questionPools: this.questionPoolResourceState,
            questionSets: state,
        });
    }
    calculateResourcesReady(resources = {}) {
        if (!resources ||
            resources.applicationForm !== R.Loaded ||
            resources.answers === R.Loading ||
            resources.questionPools === R.Loading ||
            resources.questionSets === R.Loading) {
            return false;
        }
        return true;
    }
    handleSaveAnswer(event) {
        if (this.useExternal) {
            return;
        }
        const pendingUpdate = this.questionSets.pendingActiveAnswerUpdate;
        const { answer, new_value } = event.detail;
        const updatedAnswer = L(answer, new_value);
        if (Gt(answer, new_value) ||
            (C(updatedAnswer) && !answer.is_completed) ||
            ((pendingUpdate === null || pendingUpdate === void 0 ? void 0 : pendingUpdate.id) === answer.id &&
                Gt(pendingUpdate, new_value))) {
            this.pushAnswer(updatedAnswer);
        }
    }
    componentWillUpdate() {
        this.handleSubscriptions();
    }
    render() {
        return [
            this.useExternal && this.renderExternal(),
            !this.useExternal && this.renderInternal(),
        ];
    }
    renderExternal() {
        return (h("bp-sdk-external-question-set-container", { answersResourceState: this.answersResourceState, applicationFormResourceState: this.applicationFormResourceState, config: this.config, enableUserApplicationGuard: this.enableUserApplicationGuard, hasPermissionToEdit: this.hasPermissionToEdit, isOwner: this.isOwner, locked: this.locked, pendingProcesses: this.pendingProcesses, questionPoolResourceState: this.questionPoolResourceState, questionSetResourceState: this.questionSetResourceState, questionSets: this.questionSets, queue: this.queue }));
    }
    renderQuestionSetHeader(set) {
        var _a, _b, _c, _d;
        return (h("bp-sdk-question-set-header", { applicationId: set.application_form_id, code: (_a = set.question_set) === null || _a === void 0 ? void 0 : _a.code, isActive: set.is_active, isCompleted: set.is_completed, name: (_b = set.question_set) === null || _b === void 0 ? void 0 : _b.name, setId: set.question_set_id, setTitle: (_c = set.question_set) === null || _c === void 0 ? void 0 : _c.title, tenantId: (_d = set.question_set) === null || _d === void 0 ? void 0 : _d.tenant_id }));
    }
    shouldRenderQuestionGroup(questionGroupsWithAnswersAsKey, answer) {
        return questionGroupsWithAnswersAsKey.has(answer.id);
    }
    renderQuestionSet(set) {
        // Gets multiple separate groups/nested groups
        const questionGroupsWithAnswersAsKey = rn(set, tn(set));
        if (set.is_blank) {
            return (h("bp-sdk-question-set-empty", { questionSet: set.question_set }));
        }
        return (h("bp-sdk-question-set", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, locked: this.isLocked, questionSet: set, saveHandler: this.handleSaveQuestionSet, questionGroupsWithAnswersAsKey: questionGroupsWithAnswersAsKey, shouldRenderQuestionGroup: this.shouldRenderQuestionGroup }));
    }
    renderPendingProcessesContainer() {
        return (h("bp-sdk-pending-process-container", { pendingProcesses: this.pendingProcesses }));
    }
    renderInternal() {
        if (this.isFirstRun && this.isLoadingApplication) {
            return h("bp-sdk-application-load", null);
        }
        let activeQuestionSet = this.questionSets.list[this.questionSets.list.length - 1];
        if (this.assignedQuestionSetId) {
            activeQuestionSet = this.questionSets.list.find((qs) => qs.question_set_id === this.assignedQuestionSetId);
        }
        else if (this.questionSets.active && this.questionSets.active !== '') {
            activeQuestionSet = this.questionSets.list.find((qs) => qs.question_set_id === this.questionSets.active);
        }
        if (activeQuestionSet) {
            return (h(Fragment, null, this.renderQuestionSetHeader(activeQuestionSet), this.renderQuestionSet(activeQuestionSet), this.renderPendingProcessesContainer()));
        }
    }
    doesCurrentQuestionSetHaveAPendingProcess(processes) {
        const currentProcesses = processes ? processes : this.pendingProcesses;
        if (!(currentProcesses === null || currentProcesses === void 0 ? void 0 : currentProcesses.length)) {
            return false;
        }
        return currentProcesses.some((process) => process.state !== ne.Completed &&
            process.question_set_id === this.questionSets.active);
    }
    get el() { return getElement(this); }
    static get watchers() { return {
        "queue": ["onQueueChange"],
        "enableUserApplicationGuard": ["onEnableUserApplicationGuard"],
        "hasPermissionToEdit": ["onHasPermissionToEdit"],
        "isOwner": ["onIsOwner"],
        "locked": ["onLocked"],
        "manualLocked": ["onManualLock"],
        "pendingProcesses": ["onPendingProcessesChange"],
        "isFirstRun": ["onIsFirstRun"],
        "isReady": ["onIsReady"],
        "answersResourceState": ["onAnswersResourcesStateChange"],
        "applicationFormResourceState": ["onApplicationFormResourceStateChange"],
        "questionPoolResourceState": ["onQuestionPoolResourcesStateChange"],
        "questionSetResourceState": ["onQuestionSetResourcesStateChange"]
    }; }
};

export { BpSdkQuestionSetContainer as bp_sdk_question_set_container };
